@@ -197,6 +197,8 @@ void app_normal_screen (Application *app) {
         app->fullscreen = false;
         gtk_window_unfullscreen (app->window);
         gtk_widget_show (app->playlist_area);
+        gtk_widget_hide (app->video_stop);
+        gtk_widget_hide (app->title_area);
         gtk_fixed_move (GTK_FIXED(app->window_area), app->toolbar_area, 0, 354);
         gtk_widget_show (app->toolbar_area);
         if (app->controls_timer) {
@@ -276,12 +278,14 @@ static gboolean _titleTimeout (Application *app)
 
 void app_selection_changed (Application *app)
 {
-    if (app->fullscreen && !app->controls_timer) {
-        if (app->title_timer)
-            g_source_remove (app->title_timer);
-        app->title_timer = g_timeout_add (2000, (GSourceFunc) _titleTimeout, app);
+    if (app->fullscreen) {
+        if (!app->controls_timer) {
+            if (app->title_timer)
+                g_source_remove (app->title_timer);
+            app->title_timer = g_timeout_add (2000, (GSourceFunc) _titleTimeout, app);
+        }
+        _appShowTitle (app);
     }
-    _appShowTitle (app);
 }
 
 static void _appShowPlaylistNav (GtkButton * button, Application *app)
