@@ -57,27 +57,32 @@ extern "C" {
 typedef struct _Application {
     GObject *program;
     GtkWindow *window;
-    GtkWindow *window_fullscreen;
     GtkWindow *window_downloads;
     osso_context_t *osso_context;
-    GtkWidget * main_toolbar;
-    GtkToolItem * tb_prev;
-    GtkToolItem * tb_play;
-    GtkToolItem * tb_pause;
-    GtkToolItem * tb_next;
-    GtkToolItem * tb_save;
-    GtkToolItem * tb_stop;
-    GtkToolItem * tb_location;
-    GtkToolItem * tb_go;
-    GtkToolItem * tb_progress;
+    GtkWidget *main_toolbar;
+    GtkToolItem *tb_prev;
+    GtkToolItem *tb_play;
+    GtkToolItem *tb_pause;
+    GtkToolItem *tb_next;
+    GtkToolItem *tb_save;
+    GtkToolItem *tb_stop;
+    GtkToolItem *tb_location;
+    GtkToolItem *tb_go;
+    GtkToolItem *tb_open;
+    GtkToolItem *tb_progress;
+    GtkToolItem *video_title;
+    GtkWidget *video_jump;
+    GtkWidget *video_stop;
+    GtkWidget *video_next;
+    GtkWidget *video_prev;
+    GtkWidget *video_up;
+    GtkWidget *video_down;
     GtkWidget * playlist_view;
     GtkWidget * downloads_view;
     GtkWidget * infopanel_view;
     GtkWidget * info_viewport;
     GtkWidget * html_infopanel_view;
     GtkWidget * html_viewport;
-    GtkWidget * view_area;
-    GtkWidget * view_base;
     GtkWidget * video_socket;
     GtkWidget * menu_item_playlist_copy;
     GtkWidget * menu_item_playlist_paste;
@@ -86,9 +91,12 @@ typedef struct _Application {
     GtkWidget * tb_item_playlist_commit;
     GtkWidget * location_bar;
     GtkWidget * progress_bar;
-    GtkPaned * hsplit_view;
-    GtkPaned * vsplit_view;
-    GtkWidget * isplit_view;
+    GtkWidget *window_area;
+    GtkWidget *view_area;
+    GtkWidget *title_area;
+    GtkWidget *playlist_area;
+    GtkWidget *toolbar_area;
+    GtkWidget *info_area;
     GtkCellRenderer * playlist_cell_renderer;
     void *control;
     void *viewarea;
@@ -99,6 +107,8 @@ typedef struct _Application {
     bool fullscreen;
     bool top_most_window;
     int playing;
+    guint controls_timer;
+    guint title_timer;
 } Application;
 
 GtkWidget * createTreeView (Application * app);
@@ -134,10 +144,7 @@ void expandSelectedList (Application *app);
 void cb_favorites_add (Application *app);
 void progressValueChanged(GtkWidget *w, Application * app);
 gboolean cb_scheduledPaint (void * p);
-gboolean cbViewAreaFullscreenMapped (GtkWidget *w, GdkEvent *, Application *a);
-void cbViewAreaFullscreenUnmapped (GtkWidget *w, Application *a);
 void cbPluginAdded (GtkSocket *socket, Application *app);
-void cb_fullscreen_destoyed (GtkObject *o, Application *app);
 
 void save_locationbar (Application * app);
 gboolean locationbarGainFocus (GtkWidget *, GdkEventFocus *, Application *app);
@@ -156,6 +163,8 @@ void app_set_playing (Application *app, int) MAEMO_NO_EXPORT;
 void app_set_title (const char *title, Application *app) MAEMO_NO_EXPORT;
 gchar *app_file_chooser (Application *app, const char *path, GtkFileChooserAction act);
 void app_store_save_directory (Application *app, gchar *path);
+void app_show_controls (Application *app);
+void app_selection_changed (Application *app);
 
 void openFile (Application *app, const gchar *path) MAEMO_NO_EXPORT;
 void saveFile (Application *app, bool as_xml) MAEMO_NO_EXPORT;
