@@ -308,8 +308,9 @@ void Control::deinit () {
 }
 
 static bool needsScreenBlanking (Application *app) {
-    return (app->top_most_window || app->fullscreen) &&
+    return app->top_most_window &&
         CONTROL(app)->playlist_data->current &&
+        CONTROL(app)->playlist_data->document->state != Node::state_deferred &&
         (CONTROL(app)->playlist_data->current->id == SMIL::id_node_smil ||
          (CONTROL(app)->process ()->playing () &&
           CONTROL(app)->process ()->hasVideo ()));
@@ -368,9 +369,8 @@ void Control::play () {
             if (cur_item_playing)
                 cur_item_playing->defer ();
         }
+        app_update_screen_blanking (m_app);
     } else {
-        //gtk_paned_set_position (m_app->vsplit_view, VSPLIT);
-        //gtk_container_resize_children (GTK_CONTAINER (m_app->vsplit_view));
         if (!applyBackRequest () && playlist_data->document) {
             playCurrent ();
         }
@@ -389,7 +389,6 @@ void Control::stop (bool keep_fullscreen) {
     if (playlist_data->document &&
             playlist_data->document->state > Node::state_init) {
         playlist_data->document->reset ();
-        //gtk_paned_set_position (m_app->vsplit_view, 40);
         setCurrent (0L);
     }
     VIEWAREA(m_app)->reset ();
@@ -731,8 +730,10 @@ void Control::stateElementChanged (Node* n, Node::State os, Node::State ns) {
             //VIEWAREA(m_app)->setEventFiltering (m_app, true);
             app_set_playing (m_app, PLAYING);
         }
-        if (n->id == SMIL::id_node_body)
+        if (n->id == SMIL::id_node_body) {
+            videoDetected ();
             updateViewAreaSizes (); // move away video widget
+        }
         if (n->isPlayable () &&
                 n->mrl ()->view_mode == Mrl::SingleMode) {
             Node *p = n->parentNode();
@@ -812,9 +813,7 @@ void Control::stateChanged (Process * p, Process::State os, Process::State ns) {
     } else if (ns == Process::Paused &&
             playlist_data->document->state != Node::state_deferred &&
             !playlist_data->document->document ()->postponed ()) {
-        if ((m_app->window_fullscreen &&
-                gtk_window_has_toplevel_focus (GTK_WINDOW (m_app->window_fullscreen))) ||
-                gtk_window_has_toplevel_focus (m_app->window))
+        if (gtk_window_has_toplevel_focus (m_app->window))
             m_process->pause ();
         else
             playlist_data->document->defer ();
@@ -891,10 +890,6 @@ void Control::addRecent (const String &url, const String &title) {
 
 void Control::setCurrentSelected (NodePtr node) {
     current_selected = node;
-    if (m_app->fullscreen && VIEWAREA(m_app)->controls)
-        gdk_window_clear_area_e (VIEWAREA(m_app)->controls,
-                110, 0, 410, 60);
-        //gdk_window_invalidate_rect (VIEWAREA(m_app)->controls, NULL, false);
 }
 
 void Control::errorMsg (const String & msg) {
@@ -1030,14 +1025,35 @@ void KMPlayer::jump (Node *n, Control *ctr) {
 }
 
 void app_set_info_content (Application *app, const char *s, bool plaintext) {
+    if (!app->fullscreen) {
+        if (!s || !*s)
+            gtk_widget_hide (app->info_area);
+        else
+            gtk_widget_show (app->info_area);
+    }
     if (!plaintext) {
         gtk_widget_hide (app->info_viewport);
         gtk_widget_show (app->html_viewport);
-        if (!s[0])
+        if (!s[0]) {
             gtk_html_load_empty (GTK_HTML (app->html_infopanel_view));
-        else
+        } else {
+            int w, h;
+            gtk_widget_get_size_request (app->info_area, &w, &h);
+            if (h != 140) {
+                gtk_widget_set_size_request (app->info_area, 400, 140);
+                gtk_fixed_move (GTK_FIXED (app->window_area),
+                        app->info_area, 400, 214);
+            }
             gtk_html_load_from_string(GTK_HTML(app->html_infopanel_view), s,-1);
+        }
     } else {
+        int w, h;
+        gtk_widget_get_size_request (app->info_area, &w, &h);
+        if (h != 354) {
+            gtk_fixed_move (GTK_FIXED (app->window_area),
+                    app->info_area, 400, 0);
+            gtk_widget_set_size_request (app->info_area, 400, 354);
+        }
         gtk_widget_hide (app->html_viewport);
         gtk_text_buffer_set_text (gtk_text_view_get_buffer
                 (GTK_TEXT_VIEW (app->infopanel_view)), s, -1);
@@ -1049,6 +1065,7 @@ void cbPluginAdded (GtkSocket *socket, Application *app) {
 #ifdef __ARMEL__
     Control *ctr = CONTROL(app);
     debugLog () << "plugin embedded\n";
+    ctr->videoDetected ();
     ((NpPlayer *)ctr->npp)->pluginEmbedded ();
 #endif
 }
@@ -1260,13 +1277,15 @@ gboolean cb_keyPressed (GtkWidget *, GdkEventKey * e, Application *app) {
                 CONTROL(app)->process ()->volume (-2, false);
             break;
         case GDK_Left:
-            if (gtk_window_get_focus (app->window) == app->playlist_view)
+            if (gtk_window_get_focus (app->window) == app->playlist_view ||
+                    testFullscreenPlaylist (app))
                 collapseSelectedList (app);
             else if (CONTROL(app)->process ()->playing ())
                 CONTROL(app)->process ()->seek (-200, false); // 20s
             break;
         case GDK_Right:
-            if (gtk_window_get_focus (app->window) == app->playlist_view)
+            if (gtk_window_get_focus (app->window) == app->playlist_view ||
+                    testFullscreenPlaylist (app))
                 expandSelectedList (app);
             else if (CONTROL(app)->process ()->playing ())
                 CONTROL(app)->process ()->seek (200, false); // 20s
@@ -1288,11 +1307,7 @@ gboolean cb_keyPressed (GtkWidget *, GdkEventKey * e, Application *app) {
                 nextSelected (app);
             break;
         case GDK_Escape:
-            if (testFullscreenPlaylist (app))
-                VIEWAREA(app)->controlsVisible (app, true);
-            else
-                return true;
-            break;
+            return true;
         default:
             KMPlayer::debugLog () << "Keypress " << e->keyval << KMPlayer::endl;
     }
@@ -1305,6 +1320,7 @@ void progressValueChanged(GtkWidget *w, Application * app) {
         int p = hildon_seekbar_get_position(HILDON_SEEKBAR (app->progress_bar));
         CONTROL(app)->process ()->seek (p, true);
         //debugLog () << "progressBarClicked " << p << endl;
+        app_show_controls (app);
     }
 }
 
@@ -1666,6 +1682,11 @@ void Control::updateDownload (Node *node, int percentage)
     }
 }
 
+void Control::videoDetected ()
+{
+    app_full_screen (m_app);
+}
+
 static gboolean downloadPageDestroyed (GtkObject *, Application *app)
 {
     debugLog() << "Download page destroyed\n";
