@@ -369,6 +369,7 @@ void collapseSelectedList (Application *app)
         }
         gtk_tree_view_set_cursor (tree, path, NULL, false);
         gtk_tree_path_free (path);
+        app_selection_changed (app);
     }
 }
 
@@ -385,6 +386,7 @@ void expandSelectedList (Application *app)
             gtk_tree_view_expand_row (tree, path, FALSE);
         }
         gtk_tree_path_free (path);
+        app_selection_changed (app);
     }
 }
 
@@ -487,7 +489,7 @@ setPlaylistEdit (Application *app, PlayListData *pld, bool editable)
             "editable", editable, "cursor-visible", editable, 0L);
     pld->edit_mode = editable;
     pld->updated_document = NULL;
-    gtk_paned_set_position (app->vsplit_view, editable ? 0 : VSPLIT);
+    //gtk_paned_set_position (app->vsplit_view, editable ? 0 : VSPLIT);
     g_idle_add ((GSourceFunc) delayedUpdateTree, (gpointer) app);
 }
 
@@ -662,6 +664,7 @@ void KMPlayer::nextSelected (Application *app) {
             }
         }
         gtk_tree_path_free (path);
+        app_selection_changed (app);
     }
 }
 
@@ -678,6 +681,7 @@ void KMPlayer::previousSelected (Application *app) {
         else if (gtk_tree_path_up (path))
             gtk_tree_selection_select_path (selection, path);
         gtk_tree_path_free (path);
+        app_selection_changed (app);
     }
 }
 
