@@ -1681,6 +1681,8 @@ void MouseVisitor::surfaceEvent (Node *node, Surface *s) {
     IRect scr = matrix.toScreen (rect);
     int rx = scr.x(), ry = scr.y(), rw = scr.width(), rh = scr.height();
     const bool inside = x > rx && x < rx+rw && y > ry && y< ry+rh;
+    const bool had_mouse = s->has_mouse;
+    s->has_mouse = inside;
     if (deliverAndForward (node, s, inside, true) &&
             (inside || s->has_mouse) &&
             s->firstChild () && s->firstChild ()->node) {
@@ -1690,7 +1692,6 @@ void MouseVisitor::surfaceEvent (Node *node, Surface *s) {
         s->firstChild ()->node->accept (this);
         matrix = m;
     }
-    s->has_mouse = inside;
 }
 
 KDE_NO_EXPORT void MouseVisitor::visit (SMIL::MediaType *mt) {
@@ -1800,8 +1801,6 @@ public:
 
 KDE_NO_CDTOR_EXPORT ViewArea::ViewArea (Application *app)
  : d (new ViewAreaPrivate (this)),
-   controls (NULL),
-   controls_timer (0),
    aspect (0.0),
    m_app (app),
    widget (NULL),
@@ -1816,7 +1815,6 @@ KDE_NO_CDTOR_EXPORT ViewArea::ViewArea (Application *app)
    m_fullscreen (false),
    m_event_filter_on (false),
    m_updaters_enabled (true),
-   m_controls_overlap (true),
    m_video_filter (true) {
 }
 
@@ -1903,8 +1901,6 @@ KDE_NO_EXPORT void ViewArea::resizeEvent () {
     if (w <= 0 || h <= 0)
         return;
     updateSurfaceBounds ();
-    if (controls_timer && !m_controls_overlap)
-        h -= 60;
     if (video_node && Mrl::SingleMode == video_node->mrl ()->view_mode)
         setAudioVideoGeometry (IRect (x, y, w, h), 0L);
 }
@@ -2189,13 +2185,10 @@ static
 GdkFilterReturn videoWidgetFilter (GdkXEvent *xe, GdkEvent *e, Application *a) {
     XEvent *event = (XEvent *) xe;
     ViewArea *view_area = VIEWAREA(a);
-    static Time down_time;
-    static int down_x;
-    static int down_y;
 
-    if (view_area->controls &&
-            event->xany.window == GDK_DRAWABLE_XID (view_area->controls))
-        return GDK_FILTER_CONTINUE;
+#ifdef DEBUG_XFILTER
+    debugLog() << "videoWidgetFilter" << endl;
+#endif
 
     switch (event->xany.type) {
     case KeyPress:
@@ -2258,29 +2251,16 @@ GdkFilterReturn videoWidgetFilter (GdkXEvent *xe, GdkEvent *e, Application *a) {
         IRect vr = view_area->videoGeometry ();
         if (a->fullscreen &&
                 (event->xany.window == w &&
-                 event->xbutton.x > 720 && event->xbutton.y < 80) ||
+                 event->xbutton.y < 400 &&
+                 ((event->xbutton.x > 720 &&
+                   event->xbutton.y > 80) ||
+                  event->xbutton.x <= 720)) ||
                 (event->xany.window == i &&
-                 event->xbutton.x + vr.x () > 720 &&
-                 event->xbutton.y + vr.y () < 80)) {
-            if (!view_area->controls_timer)
-                updatePlayTree (a);
-            view_area->controlsVisible (a, true);
-        } else if (event->xany.window == w || event->xany.window == i) {
-            if (event->xbutton.time - down_time < 500 &&
-                    abs (down_x - event->xbutton.x) < 80 &&
-                    abs (down_y - event->xbutton.y) < 80) {
-                view_area->prepareFullscreenToggle ();
-                if (a->fullscreen)
-                    app_normal_screen (a);
-                else
-                    app_full_screen (a);
-                down_time = 0;
-                return GDK_FILTER_REMOVE;
-            } else {
-                down_x = event->xbutton.x;
-                down_y = event->xbutton.y;
-                down_time = event->xbutton.time;
-            }
+                 event->xbutton.y + vr.y () < 400 &&
+                 ((event->xbutton.x + vr.x () > 720 &&
+                   event->xbutton.y + vr.y () > 80) ||
+                  event->xbutton.x + vr.x () <= 720))) {
+            app_show_controls (a);
         }
     }
     // fall through
@@ -2309,103 +2289,6 @@ GdkFilterReturn videoWidgetFilter (GdkXEvent *xe, GdkEvent *e, Application *a) {
     return GDK_FILTER_CONTINUE;
 }
 
-static
-GdkFilterReturn controlsFilter (GdkXEvent *xe, GdkEvent *e, Application *app) {
-    XEvent *event = (XEvent *) xe;
-    ViewArea *view_area = VIEWAREA(app);
-
-    if (event->xany.window != GDK_DRAWABLE_XID (view_area->controls))
-        return GDK_FILTER_CONTINUE;
-
-    static int downx, downy;
-    static Time down_time;
-
-    switch (event->xany.type) {
-    case ButtonPress:
-        if (app->fullscreen) {
-            int x, w = -1;
-            if (event->xbutton.x < 100) {
-                previousSelected (app);
-                x = 0;
-                w = 100;
-            } else if (event->xbutton.x > 705) {
-                nextSelected (app);
-                x = 705;
-                w = 95;
-            } else if (event->xbutton.x > 655 && event->xbutton.x < 705) {
-                cb_favorites_add (app);
-                x = 655;
-                w = 50;
-            } else if (event->xbutton.x > 110  && event->xbutton.x < 655) {
-                downx = event->xbutton.x;
-                down_time = event->xbutton.time;
-            }
-            if (w > 0) {
-                gdk_window_clear_area_e (VIEWAREA(app)->controls, x, 0, w, 60);
-                view_area->controlsVisible (app, true);
-            }
-        }
-        break;
-    case ButtonRelease:
-        if (event->xbutton.x > 110  && event->xbutton.x < 655) {
-            int dx = event->xbutton.x - downx;
-            if (-20 < dx && dx < 20 && event->xbutton.time - down_time < 1000) {
-                gdk_window_clear_area_e (VIEWAREA(app)->controls, 110, 0, 545, 60);
-                rowSelected (app);
-            } else {
-                view_area->controlsVisible (app, false);
-            }
-        }
-        break;
-    case Expose:
-        if (!event->xexpose.count && event->xany.window &&
-                event->xany.window == GDK_DRAWABLE_XID (view_area->controls)) {
-            cairo_t *cr = gdk_cairo_create (view_area->controls);
-            cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-            cairo_set_source_rgb (cr, 32.0 / 255, 32.0 / 255, 1);
-            cairo_rectangle (cr, 0, 0, 655, 60);
-            cairo_fill (cr);
-            cairo_rectangle (cr, 705, 0, 95, 60);
-            cairo_fill (cr);
-            cairo_set_source_rgb (cr, 32.0 / 255, 1, 48.0 / 255);
-            cairo_rectangle (cr, 655, 0, 50, 60);
-            cairo_fill (cr);
-            GValue icon = { 0 , };
-            GValue text = { 0 , };
-            if (playlist_selected (app, &icon, &text)) {
-                GdkPixbuf *pix = (GdkPixbuf *) g_value_get_object (&icon);
-                const gchar *val = g_value_get_string (&text);
-                if (pix) {
-                    int pixw = gdk_pixbuf_get_width (pix);
-                    cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
-                    gdk_cairo_set_source_pixbuf (cr, pix, 127, 17);
-                    cairo_rectangle (cr, 127, 17, pixw, pixw);
-                    cairo_fill (cr);
-                    cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-                }
-                cairo_set_source_rgb (cr, 0.8, 0.8, 0);
-                cairo_move_to (cr, 157, 10);
-                PangoLayout *layout = pango_cairo_create_layout (cr);
-                pango_layout_set_width (layout, 483 * PANGO_SCALE);
-                pango_layout_set_text (layout, val, -1);
-                PangoFontDescription *desc = pango_font_description_new ();
-                pango_font_description_set_family (desc, "Sans");
-                pango_font_description_set_absolute_size (desc,
-                        PANGO_SCALE * 20);
-                pango_layout_set_font_description (layout, desc);
-                pango_font_description_free (desc);
-                pango_cairo_show_layout (cr, layout);
-                g_object_unref (layout);
-                g_value_unset (&icon);
-                g_value_unset (&text);
-            }
-            cairo_destroy (cr);
-            return GDK_FILTER_REMOVE;
-        }
-    }
-    return GDK_FILTER_CONTINUE;
-}
-
 KDE_NO_EXPORT void ViewArea::setEventFiltering (Application *app, bool on) {
     if (on && !m_event_filter_on)
         gdk_window_add_filter (NULL, (GdkFilterFunc) videoWidgetFilter, app);
@@ -2448,33 +2331,6 @@ unsigned long ViewArea::videoXId () const {
     return gtk_socket_get_id (GTK_SOCKET (m_app->video_socket));
 }
 
-static gboolean cb_controlsTimeout (Application *app) {
-    VIEWAREA(app)->controls_timer = 0;
-    VIEWAREA(app)->controlsVisible (app, false);
-    return false;
-}
-
-void ViewArea::controlsVisible (Application *app, bool show) {
-    if (controls_timer)
-        g_source_remove (controls_timer);
-    if (show) {
-        bool update_sizes = false;
-        if (!controls_timer) {
-            gdk_window_move (controls, 0, 420);
-            update_sizes = true;
-        }
-        controls_timer = g_timeout_add (10000, (GSourceFunc) cb_controlsTimeout, app);
-        if (update_sizes)
-            CONTROL(app)->updateViewAreaSizes ();
-    } else {
-        controls_timer = 0;
-        if (controls) {
-            gdk_window_move (controls, 0, 490);
-            CONTROL(app)->updateViewAreaSizes ();
-        }
-    }
-}
-
 //------------------------------------------------------------------------------
 
 void cb_view_area_button_press (GtkWidget *w, GdkEventButton *e, Application * app) {
@@ -2559,53 +2415,10 @@ static GdkBitmap *createControlsMask () {
     return bitmap;
 }
 
-gboolean cbViewAreaFullscreenMapped (GtkWidget *w, GdkEvent *, Application *a) {
-    ViewArea *view_area = VIEWAREA(a);
-    gtk_window_fullscreen (GTK_WINDOW (a->window_fullscreen));
-    if (!view_area->controls) {
-        GdkWindowAttr attributes;
-        attributes.window_type = GDK_WINDOW_CHILD;
-        attributes.x = 0;
-        attributes.y = 0;
-        attributes.width = 800;
-        attributes.height = 60;
-        attributes.wclass = GDK_INPUT_OUTPUT;
-        attributes.visual = gtk_widget_get_visual (w);
-        attributes.colormap = gtk_widget_get_colormap (w);
-        attributes.event_mask = gtk_widget_get_events (w) |
-            GDK_SUBSTRUCTURE_MASK | GDK_EXPOSURE_MASK |
-            GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK;
-        attributes.event_mask &= ~GDK_KEY_PRESS_MASK;
-        //    ~(GDK_KEY_PRESS_MASK | GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK);
-        gint mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
-        view_area->controls = gdk_window_new (a->view_area->window, &attributes, mask);
-        gdk_window_add_filter (view_area->controls, (GdkFilterFunc) controlsFilter, a);
-        GdkBitmap *bitmap = createControlsMask ();
-        gdk_window_shape_combine_mask (view_area->controls, bitmap, 0, 0);
-        gdk_window_show (view_area->controls);
-    } else {
-        gdk_window_raise (view_area->controls);
-    }
-    view_area->controlsVisible (a, false);
-    return false;
-}
-
-void cbViewAreaFullscreenUnmapped (GtkWidget *w, Application *a) {
-    ViewArea *view_area = VIEWAREA(a);
-    view_area->controlsVisible (a, false);
-}
-
-void cb_fullscreen_destoyed (GtkObject *o, Application *app) {
-    if (app->fullscreen) {
-        ViewArea *view_area = VIEWAREA(app);
-        app->fullscreen = false;
-        app->window_fullscreen = NULL;
-        view_area->controls = NULL;
-        view_area->controlsVisible (app, false);
-    }
-}
-
 gboolean cb_scheduledPaint (void * vp) {
+#ifdef DEBUG_TIMERS
+    debugLog() << "cb_scheduledPaint" << endl;
+#endif
     return static_cast <ViewArea *> (vp)->timeoutPaintEvent ();
 }
 
